==> sship_0.7.4.tar.gz: sship/tests/testthat/gh_api_response/api.github.com/none/existent/endpoint.R <==
structure(list(url = "https://api.github.com/none/existent/endpoint", 
    status_code = 404L, headers = structure(list(server = "GitHub.com", 
        date = "Fri, 28 Jan 2022 11:53:27 GMT", `content-type` = "application/json; charset=utf-8", 
        `x-github-media-type` = "github.v3", `access-control-expose-headers` = "ETag, Link, Location, Retry-After, X-GitHub-OTP, X-RateLimit-Limit, X-RateLimit-Remaining, X-RateLimit-Used, X-RateLimit-Resource, X-RateLimit-Reset, X-OAuth-Scopes, X-Accepted-OAuth-Scopes, X-Poll-Interval, X-GitHub-Media-Type, X-GitHub-SSO, X-GitHub-Request-Id, Deprecation, Sunset", 
        `access-control-allow-origin` = "*", `strict-transport-security` = "max-age=31536000; includeSubdomains; preload", 
        `x-frame-options` = "deny", `x-content-type-options` = "nosniff", 
        `x-xss-protection` = "0", `referrer-policy` = "origin-when-cross-origin, strict-origin-when-cross-origin", 
        `content-security-policy` = "default-src 'none'", vary = "Accept-Encoding, Accept, X-Requested-With", 
        `content-encoding` = "gzip", `x-ratelimit-limit` = "60", 
        `x-ratelimit-remaining` = "55", `x-ratelimit-reset` = "1643374086", 
        `x-ratelimit-resource` = "core", `x-ratelimit-used` = "5", 
        `content-length` = "91", `x-github-request-id` = "8ED8:730B:2128494:21B867A:61F3D937"), class = c("insensitive", 
    "list")), all_headers = list(list(status = 404L, version = "HTTP/2", 
        headers = structure(list(server = "GitHub.com", date = "Fri, 28 Jan 2022 11:53:27 GMT", 
            `content-type` = "application/json; charset=utf-8", 
            `x-github-media-type` = "github.v3", `access-control-expose-headers` = "ETag, Link, Location, Retry-After, X-GitHub-OTP, X-RateLimit-Limit, X-RateLimit-Remaining, X-RateLimit-Used, X-RateLimit-Resource, X-RateLimit-Reset, X-OAuth-Scopes, X-Accepted-OAuth-Scopes, X-Poll-Interval, X-GitHub-Media-Type, X-GitHub-SSO, X-GitHub-Request-Id, Deprecation, Sunset", 
            `access-control-allow-origin` = "*", `strict-transport-security` = "max-age=31536000; includeSubdomains; preload", 
            `x-frame-options` = "deny", `x-content-type-options` = "nosniff", 
            `x-xss-protection` = "0", `referrer-policy` = "origin-when-cross-origin, strict-origin-when-cross-origin", 
            `content-security-policy` = "default-src 'none'", 
            vary = "Accept-Encoding, Accept, X-Requested-With", 
            `content-encoding` = "gzip", `x-ratelimit-limit` = "60", 
            `x-ratelimit-remaining` = "55", `x-ratelimit-reset` = "1643374086", 
            `x-ratelimit-resource` = "core", `x-ratelimit-used` = "5", 
            `content-length` = "91", `x-github-request-id` = "8ED8:730B:2128494:21B867A:61F3D937"), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = charToRaw("{\"message\":\"Not Found\",\"documentation_url\":\"https://docs.github.com/rest\"}"), 
    date = structure(1643370807, class = c("POSIXct", "POSIXt"
    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 4.6e-05, 
    connect = 4.7e-05, pretransfer = 0.000225, starttransfer = 0.145688, 
    total = 0.145864)), class = "response")

==> sship_0.8.0.tar.gz: sship/tests/testthat/gh_api_response/api.github.com/none/existent/endpoint.R <==
structure(list(url = "https://api.github.com/none/existent/endpoint", 
    status_code = 404L, headers = structure(list(server = "GitHub.com", 
        date = "Fri, 05 Aug 2022 08:06:55 GMT", `content-type` = "application/json; charset=utf-8", 
        `x-github-media-type` = "github.v3", `access-control-expose-headers` = "ETag, Link, Location, Retry-After, X-GitHub-OTP, X-RateLimit-Limit, X-RateLimit-Remaining, X-RateLimit-Used, X-RateLimit-Resource, X-RateLimit-Reset, X-OAuth-Scopes, X-Accepted-OAuth-Scopes, X-Poll-Interval, X-GitHub-Media-Type, X-GitHub-SSO, X-GitHub-Request-Id, Deprecation, Sunset", 
        `access-control-allow-origin` = "*", `strict-transport-security` = "max-age=31536000; includeSubdomains; preload", 
        `x-frame-options` = "deny", `x-content-type-options` = "nosniff", 
        `x-xss-protection` = "0", `referrer-policy` = "origin-when-cross-origin, strict-origin-when-cross-origin", 
        `content-security-policy` = "default-src 'none'", vary = "Accept-Encoding, Accept, X-Requested-With", 
        `content-encoding` = "gzip", `x-ratelimit-limit` = "60", 
        `x-ratelimit-remaining` = "57", `x-ratelimit-reset` = "1659690415", 
        `x-ratelimit-resource` = "core", `x-ratelimit-used` = "3", 
        `content-length` = "91", `x-github-request-id` = "69C1:FF9F:3F4CA3E:40D27AF:62ECCF9F"), class = c("insensitive", 
    "list")), all_headers = list(list(status = 404L, version = "HTTP/2", 
        headers = structure(list(server = "GitHub.com", date = "Fri, 05 Aug 2022 08:06:55 GMT", 
            `content-type` = "application/json; charset=utf-8", 
            `x-github-media-type` = "github.v3", `access-control-expose-headers` = "ETag, Link, Location, Retry-After, X-GitHub-OTP, X-RateLimit-Limit, X-RateLimit-Remaining, X-RateLimit-Used, X-RateLimit-Resource, X-RateLimit-Reset, X-OAuth-Scopes, X-Accepted-OAuth-Scopes, X-Poll-Interval, X-GitHub-Media-Type, X-GitHub-SSO, X-GitHub-Request-Id, Deprecation, Sunset", 
            `access-control-allow-origin` = "*", `strict-transport-security` = "max-age=31536000; includeSubdomains; preload", 
            `x-frame-options` = "deny", `x-content-type-options` = "nosniff", 
            `x-xss-protection` = "0", `referrer-policy` = "origin-when-cross-origin, strict-origin-when-cross-origin", 
            `content-security-policy` = "default-src 'none'", 
            vary = "Accept-Encoding, Accept, X-Requested-With", 
            `content-encoding` = "gzip", `x-ratelimit-limit` = "60", 
            `x-ratelimit-remaining` = "57", `x-ratelimit-reset` = "1659690415", 
            `x-ratelimit-resource` = "core", `x-ratelimit-used` = "3", 
            `content-length` = "91", `x-github-request-id` = "69C1:FF9F:3F4CA3E:40D27AF:62ECCF9F"), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = charToRaw("{\"message\":\"Not Found\",\"documentation_url\":\"https://docs.github.com/rest\"}"), 
    date = structure(1659686815, class = c("POSIXct", "POSIXt"
    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 2.5e-05, 
    connect = 2.6e-05, pretransfer = 0.000134, starttransfer = 0.226268, 
    total = 0.226364)), class = "response")
